Python Library Template (PyLibTemplate)
=======================================

``pylibtemplate`` (short for 'Python Library Template') is a Python library that
generates ``git`` repository templates for building Python libraries that are
suitable for publication on PyPI.



Instructions for installing and uninstalling ``pylibtemplate``
--------------------------------------------------------------

For instructions on installing the ``pylibtemplate`` library, see the
:ref:`installation_instructions_sec` page.



Learning how to use ``pylibtemplate``
-------------------------------------

The primary purpose of the ``pylibtemplate`` library is to facilitate in the
creation of new Python libraries. See the
:ref:`how_to_create_a_python_library_using_pylibtemplate_sec` page for
instructions on creating Python libraries using ``pylibtemplate``.

For those new to the ``pylibtemplate`` library, it is recommended that they take
a look at the :ref:`examples_sec` page, which contain code examples that show
how one can use the ``pylibtemplate`` library. While going through the examples,
readers can consult the :ref:`reference_guide_sec` to understand what each line
of code is doing.



Contents
--------

.. toctree::
   :maxdepth: 6
   :numbered:

   home <self>
   INSTALL
   Reference <_autosummary/pylibtemplate>
   examples
   literature
   license



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
